@@ -2,7 +2,7 @@ package LinkEmbedder::Link::Imgur;
 use Mojo::Base 'LinkEmbedder::Link';
 
 has provider_name => 'Imgur';
-has provider_url => sub { Mojo::URL->new('http://imgur.com') };
+has provider_url => sub { Mojo::URL->new('https://imgur.com') };
 
 sub _learn_from_dom {
   my ($self, $dom) = @_;
